@@ -1133,7 +1133,7 @@ find_prev_clicked_cb (GtkWidget *widget,
   if (priv->hide_timeout)
     {
       g_source_remove (priv->hide_timeout);
-      priv->hide_timeout = g_timeout_add (5000, hide_find_pane, defbox);
+      priv->hide_timeout = g_timeout_add_seconds (5, hide_find_pane, defbox);
     }
 }
 
@@ -1227,7 +1227,7 @@ find_next_clicked_cb (GtkWidget *widget,
   if (priv->hide_timeout)
     {
       g_source_remove (priv->hide_timeout);
-      priv->hide_timeout = g_timeout_add (5000, hide_find_pane, defbox);
+      priv->hide_timeout = g_timeout_add_seconds (5, hide_find_pane, defbox);
     }
 }
 
@@ -1263,7 +1263,7 @@ find_entry_changed_cb (GtkWidget *widget,
   if (priv->hide_timeout)
     {
       g_source_remove (priv->hide_timeout);
-      priv->hide_timeout = g_timeout_add (5000, hide_find_pane, defbox);
+      priv->hide_timeout = g_timeout_add_seconds (5, hide_find_pane, defbox);
     }
 }
 
@@ -1726,7 +1726,7 @@ gdict_defbox_real_show_find (GdictDefbox *defbox)
   
   gtk_widget_grab_focus (defbox->priv->find_entry);
 
-  defbox->priv->hide_timeout = g_timeout_add (5000, hide_find_pane, defbox);
+  defbox->priv->hide_timeout = g_timeout_add_seconds (5, hide_find_pane, defbox);
 }
 
 static void
@@ -1992,7 +1992,7 @@ gdict_defbox_set_context (GdictDefbox  *defbox,
  *
  * Gets the #GdictContext used by @defbox.
  *
- * Return value: a #GdictContext.
+ * Return value: (transfer none): a #GdictContext.
  *
  * Since: 0.1
  */
@@ -2098,7 +2098,7 @@ gdict_defbox_set_show_find (GdictDefbox *defbox,
       gtk_widget_grab_focus (priv->find_entry);
 
       if (!priv->hide_timeout)
-        priv->hide_timeout = g_timeout_add (5000, hide_find_pane, defbox);
+        priv->hide_timeout = g_timeout_add_seconds (5, hide_find_pane, defbox);
     }
   else
     {
@@ -2783,7 +2783,7 @@ gdict_defbox_jump_to_definition (GdictDefbox *defbox,
 /**
  * gdict_defbox_get_text:
  * @defbox: a #GdictDefbox
- * @length: return location for the text length or %NULL
+ * @length: (out) (optional): return location for the text length or %NULL
  *
  * Gets the full contents of @defbox.
  *
@@ -2819,7 +2819,7 @@ gdict_defbox_get_text (GdictDefbox *defbox,
 /**
  * gdict_defbox_set_font_name:
  * @defbox: a #GdictDefbox
- * @font_name: a font description, or %NULL
+ * @font_name: (nullable): a font description, or %NULL
  *
  * Sets @font_name as the font for @defbox. It calls internally
  * pango_font_description_from_string() and gtk_widget_modify_font().
